# Generated by Django 3.1.1 on 2021-01-06 08:03

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0012_index_additions'),
        ('aastatistics', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='zKillStatsFilter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=500)),
                ('description', models.CharField(max_length=500)),
                ('kill_count', models.IntegerField(default=0)),
                ('months', models.IntegerField(default=1)),
            ],
            options={
                'verbose_name': 'Smart Filter: zKill: Kills in Period',
                'verbose_name_plural': 'Smart Filter: zKill: Kills in Period',
            },
        ),
        migrations.AlterField(
            model_name='statscharacter',
            name='character',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='character_stats', to='eveonline.evecharacter'),
        ),
        migrations.AlterField(
            model_name='statscharacter',
            name='last_update',
            field=models.DateTimeField(default=datetime.datetime(2019, 12, 28, 8, 3, 21, 524661)),
        ),
        migrations.AlterField(
            model_name='zkillmonth',
            name='last_update',
            field=models.DateTimeField(default=datetime.datetime(2019, 12, 28, 8, 3, 21, 525255)),
        ),
    ]
 