# Generated by AaronKable on 2021-07-15 08:13
from django.db import migrations


def gen_date_str_fwd(apps, schema_editor):
    MyModel = apps.get_model('aastatistics', 'zKillMonth')
    for row in MyModel.objects.all():
        row.date_str = (str(row.year)+str(row.month).zfill(2))
        row.save(update_fields=['date_str'])


class Migration(migrations.Migration):

    dependencies = [
        ('aastatistics', '0003_auto_20210715_1031'),
    ]

    operations = [
        migrations.RunPython(gen_date_str_fwd, reverse_code=migrations.RunPython.noop),
    ]
