# Generated by Django 3.2.5 on 2021-07-15 10:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aastatistics', '0005_alter_zkillmonth_date_str'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='zkillmonth',
            index=models.Index(fields=['date_str'], name='aastatistic_date_st_cf872c_idx'),
        ),
        migrations.AddIndex(
            model_name='zkillmonth',
            index=models.Index(fields=['year'], name='aastatistic_year_da44d7_idx'),
        ),
        migrations.AddIndex(
            model_name='zkillmonth',
            index=models.Index(fields=['month'], name='aastatistic_month_52ce12_idx'),
        ),
    ]
