# Generated by Django 3.1.4 on 2021-01-03 10:38

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('eveonline', '0012_index_additions'),
    ]

    operations = [
        migrations.CreateModel(
            name='StatsCharacter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('isk_destroyed', models.BigIntegerField(default=0)),
                ('isk_lost', models.BigIntegerField(default=0)),
                ('all_time_sum', models.IntegerField(default=0)),
                ('gang_ratio', models.IntegerField(default=0)),
                ('ships_destroyed', models.IntegerField(default=0)),
                ('ships_lost', models.IntegerField(default=0)),
                ('solo_destroyed', models.IntegerField(default=0)),
                ('solo_lost', models.IntegerField(default=0)),
                ('active_pvp_kills', models.IntegerField(default=0)),
                ('last_kill', models.DateTimeField(default=None, null=True)),
                ('last_update', models.DateTimeField(default=datetime.datetime(2019, 12, 25, 10, 38, 4, 421195))),
                ('zk_12m', models.IntegerField(default=0)),
                ('zk_6m', models.IntegerField(default=0)),
                ('zk_3m', models.IntegerField(default=0)),
                ('character', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='zkill', to='eveonline.evecharacter')),
            ],
        ),
        migrations.CreateModel(
            name='zKillMonth',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.IntegerField(default=0)),
                ('month', models.IntegerField(default=0)),
                ('ships_destroyed', models.IntegerField(default=0)),
                ('ships_lost', models.IntegerField(default=0)),
                ('isk_destroyed', models.BigIntegerField(default=0)),
                ('isk_lost', models.BigIntegerField(default=0)),
                ('last_update', models.DateTimeField(default=datetime.datetime(2019, 12, 25, 10, 38, 4, 421869))),
                ('char', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='aastatistics.statscharacter')),
            ],
        ),
    ]
