# Generated by Django 3.2.5 on 2021-07-15 10:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aastatistics', '0004_add_date_strs'),
    ]

    operations = [
        migrations.AlterField(
            model_name='zkillmonth',
            name='date_str',
            field=models.CharField(max_length=6),
        ),
    ]
