# Generated by Django 3.2.5 on 2021-07-15 10:31

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aastatistics', '0002_auto_20210106_0803'),
    ]

    operations = [
        migrations.AddField(
            model_name='zkillmonth',
            name='date_str',
            field=models.CharField(max_length=6, null=True),
        ),
        migrations.AlterField(
            model_name='statscharacter',
            name='last_update',
            field=models.DateTimeField(default=datetime.datetime(1, 1, 1, 0, 0)),
        ),
        migrations.AlterField(
            model_name='zkillmonth',
            name='last_update',
            field=models.DateTimeField(default=datetime.datetime(1, 1, 1, 0, 0)),
        ),
    ]
